#[repr(transparent)]pub struct Fiford48hnopop(pub u32);Expand description
FIFO data read for upper data bits with no FIFO pop. May only be used if the I2S is configured for 2x 24-bit data and not using DMA.
Tuple Fields
0: u32Implementations
Sourceimpl Fiford48hnopop
impl Fiford48hnopop
Sourcepub const fn rxdata(&self) -> u32
pub const fn rxdata(&self) -> u32
Received data from the FIFO. Whether this register is used and the number of bits used depends on configuration details.
Sourcepub const fn set_rxdata(&mut self, val: u32)
pub const fn set_rxdata(&mut self, val: u32)
Received data from the FIFO. Whether this register is used and the number of bits used depends on configuration details.