nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Fifowr48h

Struct Fifowr48h 

#[repr(transparent)]
pub struct Fifowr48h(pub u32);
FIFO write data for upper data bits. May only be used if the I2S is configured for 2x 24-bit data and not using DMA.

Tuple Fields

0: u32

Implementations

Source

impl Fifowr48h

pub const fn txdata(&self) -> u32

Transmit data to the FIFO. Whether this register is used and the number of bits used depends on configuration details.

pub const fn set_txdata(&mut self, val: u32)

Transmit data to the FIFO. Whether this register is used and the number of bits used depends on configuration details.