nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
Status register for the primary channel pair.

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn busy(&self) -> Busy

Busy status for the primary channel pair. Other BUSY flags may be found in the STAT register for each channel pair.

pub const fn set_busy(&mut self, val: Busy)

Busy status for the primary channel pair. Other BUSY flags may be found in the STAT register for each channel pair.

pub const fn slvfrmerr(&self) -> bool

Slave Frame Error flag. This applies when at least one channel pair is operating as a slave. An error indicates that the incoming WS signal did not transition as expected due to a mismatch between FRAMELEN and the actual incoming I2S stream.

pub const fn set_slvfrmerr(&mut self, val: bool)

Slave Frame Error flag. This applies when at least one channel pair is operating as a slave. An error indicates that the incoming WS signal did not transition as expected due to a mismatch between FRAMELEN and the actual incoming I2S stream.

pub const fn lr(&self) -> Lr

Left/Right indication. This flag is considered to be a debugging aid and is not expected to be used by an I2S driver. Valid when one channel pair is busy. Indicates left or right data being processed for the currently busy channel pair.

pub const fn set_lr(&mut self, val: Lr)

Left/Right indication. This flag is considered to be a debugging aid and is not expected to be used by an I2S driver. Valid when one channel pair is busy. Indicates left or right data being processed for the currently busy channel pair.

pub const fn datapaused(&self) -> bool

Data Paused status flag. Applies to all I2S channels

pub const fn set_datapaused(&mut self, val: bool)

Data Paused status flag. Applies to all I2S channels