#[repr(transparent)]pub struct Fifowr48h(pub u32);Expand description
FIFO write data for upper data bits. May only be used if the I2S is configured for 2x 24-bit data and not using DMA.
Tuple Fields
0: u32Implementations
Sourceimpl Fifowr48h
impl Fifowr48h
Sourcepub const fn txdata(&self) -> u32
pub const fn txdata(&self) -> u32
Transmit data to the FIFO. Whether this register is used and the number of bits used depends on configuration details.
Sourcepub const fn set_txdata(&mut self, val: u32)
pub const fn set_txdata(&mut self, val: u32)
Transmit data to the FIFO. Whether this register is used and the number of bits used depends on configuration details.